@@ -137,15 +137,18 @@ class gitricsGroup(GitlabGroup):
                 final_values.append((user, sum(user_values) / len(user_values)))
 
             # replace ids with full user objects
-            item.ownership = [
+            full_users = [
                 d for d in self.users
                 if d.id in [x[0] for x in final_values]
             ] if self.users else list()
 
             # append ownership score to each GitlabUser object
-            for user in item.ownership:
+            for user in full_users:
                 user.score_ownership = [d for d in final_values if d[0] == user.id][0][1]
 
+            # sort by ownership score
+            item.ownership = sorted(full_users, key=lambda d: d.score_ownership, reverse=True)
+
         return result
 
     def determine_status(self, item: dict) -> str:
